@@ -23,7 +23,7 @@ import numba.cuda.core.compiler_machinery as nccm
 _termcolor = errors.termcolor()
 
 
-class SimpleTimer(object):
+class SimpleTimer:
     """
     A simple context managed timer
     """
@@ -111,7 +111,7 @@ class CompilerPass(metaclass=ABCMeta):
         return self._analysis[pass_name]
 
 
-class SSACompliantMixin(object):
+class SSACompliantMixin:
     """Mixin to indicate a pass is SSA form compliant. Nothing is asserted
     about this condition at present.
     """
@@ -137,7 +137,7 @@ class LoweringPass(CompilerPass):
     pass
 
 
-class AnalysisUsage(object):
+class AnalysisUsage:
     """This looks and behaves like LLVM's AnalysisUsage because its like that."""
 
     def __init__(self):
@@ -171,7 +171,7 @@ def debug_print(*args, **kwargs):
 pass_timings = namedtuple("pass_timings", "init run finalize")
 
 
-class PassManager(object):
+class PassManager:
     """
     The PassManager is a named instance of a particular compilation pipeline
     """
@@ -437,7 +437,7 @@ class PassManager(object):
 pass_info = namedtuple("pass_info", "pass_inst mutates_CFG analysis_only")
 
 
-class PassRegistry(object):
+class PassRegistry:
     """
     Pass registry singleton class.
     """
