@@ -61,7 +61,7 @@ class FakeOverloadDict(dict):
         return FakeOverload()
 
 
-class FakeCUDAKernel(object):
+class FakeCUDAKernel:
     """
     Wraps a @cuda.jit-ed function.
     """
@@ -181,7 +181,7 @@ class BlockThread(threading.Thread):
         else:
             target = f
 
-        super(BlockThread, self).__init__(target=target)
+        super().__init__(target=target)
         self.syncthreads_event = threading.Event()
         self.syncthreads_blocked = False
         self._manager = manager
@@ -198,7 +198,7 @@ class BlockThread(threading.Thread):
 
     def run(self):
         try:
-            super(BlockThread, self).run()
+            super().run()
         except Exception as e:
             tid = "tid=%s" % list(self.threadIdx)
             ctaid = "ctaid=%s" % list(self.blockIdx)
@@ -250,7 +250,7 @@ class BlockThread(threading.Thread):
         return "Thread <<<%s, %s>>>" % (self.blockIdx, self.threadIdx)
 
 
-class BlockManager(object):
+class BlockManager:
     """
     Manages the execution of a thread block.
 
